==> farazgoated-0.0.3-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### DDBGoated <a name="DDBGoated" id="farazgoated.DDBGoated"></a>

#### Initializers <a name="Initializers" id="farazgoated.DDBGoated.Initializer"></a>

```typescript
import { DDBGoated } from 'farazgoated'

new DDBGoated(scope: Construct, id: string, props: DDBGoatedProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.props">props</a></code> | <code><a href="#farazgoated.DDBGoatedProps">DDBGoatedProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="farazgoated.DDBGoated.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="farazgoated.DDBGoated.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="farazgoated.DDBGoated.Initializer.parameter.props"></a>

- *Type:* <a href="#farazgoated.DDBGoatedProps">DDBGoatedProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#farazgoated.DDBGoated.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="farazgoated.DDBGoated.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#farazgoated.DDBGoated.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="farazgoated.DDBGoated.isConstruct"></a>

```typescript
import { DDBGoated } from 'farazgoated'

DDBGoated.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="farazgoated.DDBGoated.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoated.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#farazgoated.DDBGoated.property.table">table</a></code> | <code>aws-cdk-lib.aws_dynamodb.Table</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="farazgoated.DDBGoated.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `table`<sup>Required</sup> <a name="table" id="farazgoated.DDBGoated.property.table"></a>

```typescript
public readonly table: Table;
```

- *Type:* aws-cdk-lib.aws_dynamodb.Table

---


## Structs <a name="Structs" id="Structs"></a>

### DDBGoatedProps <a name="DDBGoatedProps" id="farazgoated.DDBGoatedProps"></a>

#### Initializer <a name="Initializer" id="farazgoated.DDBGoatedProps.Initializer"></a>

```typescript
import { DDBGoatedProps } from 'farazgoated'

const dDBGoatedProps: DDBGoatedProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoatedProps.property.billingMode">billingMode</a></code> | <code>aws-cdk-lib.aws_dynamodb.BillingMode</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.partitionKey">partitionKey</a></code> | <code>object</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.tableClass">tableClass</a></code> | <code>aws-cdk-lib.aws_dynamodb.TableClass</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.readCapacity">readCapacity</a></code> | <code>number</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.writeCapacity">writeCapacity</a></code> | <code>number</code> | *No description.* |

---

##### `billingMode`<sup>Required</sup> <a name="billingMode" id="farazgoated.DDBGoatedProps.property.billingMode"></a>

```typescript
public readonly billingMode: BillingMode;
```

- *Type:* aws-cdk-lib.aws_dynamodb.BillingMode

---

##### `partitionKey`<sup>Required</sup> <a name="partitionKey" id="farazgoated.DDBGoatedProps.property.partitionKey"></a>

```typescript
public readonly partitionKey: object;
```

- *Type:* object

---

##### `tableClass`<sup>Required</sup> <a name="tableClass" id="farazgoated.DDBGoatedProps.property.tableClass"></a>

```typescript
public readonly tableClass: TableClass;
```

- *Type:* aws-cdk-lib.aws_dynamodb.TableClass

---

##### `readCapacity`<sup>Optional</sup> <a name="readCapacity" id="farazgoated.DDBGoatedProps.property.readCapacity"></a>

```typescript
public readonly readCapacity: number;
```

- *Type:* number

---

##### `writeCapacity`<sup>Optional</sup> <a name="writeCapacity" id="farazgoated.DDBGoatedProps.property.writeCapacity"></a>

```typescript
public readonly writeCapacity: number;
```

- *Type:* number

---

==> farazgoated-0.0.4-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### DDBGoated <a name="DDBGoated" id="farazgoated.DDBGoated"></a>

#### Initializers <a name="Initializers" id="farazgoated.DDBGoated.Initializer"></a>

```typescript
import { DDBGoated } from 'farazgoated'

new DDBGoated(scope: Construct, id: string, props: DDBGoatedProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoated.Initializer.parameter.props">props</a></code> | <code><a href="#farazgoated.DDBGoatedProps">DDBGoatedProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="farazgoated.DDBGoated.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="farazgoated.DDBGoated.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="farazgoated.DDBGoated.Initializer.parameter.props"></a>

- *Type:* <a href="#farazgoated.DDBGoatedProps">DDBGoatedProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#farazgoated.DDBGoated.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="farazgoated.DDBGoated.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#farazgoated.DDBGoated.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="farazgoated.DDBGoated.isConstruct"></a>

```typescript
import { DDBGoated } from 'farazgoated'

DDBGoated.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="farazgoated.DDBGoated.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoated.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#farazgoated.DDBGoated.property.table">table</a></code> | <code>aws-cdk-lib.aws_dynamodb.Table</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="farazgoated.DDBGoated.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `table`<sup>Required</sup> <a name="table" id="farazgoated.DDBGoated.property.table"></a>

```typescript
public readonly table: Table;
```

- *Type:* aws-cdk-lib.aws_dynamodb.Table

---


## Structs <a name="Structs" id="Structs"></a>

### DDBGoatedProps <a name="DDBGoatedProps" id="farazgoated.DDBGoatedProps"></a>

#### Initializer <a name="Initializer" id="farazgoated.DDBGoatedProps.Initializer"></a>

```typescript
import { DDBGoatedProps } from 'farazgoated'

const dDBGoatedProps: DDBGoatedProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#farazgoated.DDBGoatedProps.property.billingMode">billingMode</a></code> | <code>aws-cdk-lib.aws_dynamodb.BillingMode</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.partitionKeyName">partitionKeyName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.partitionKeyType">partitionKeyType</a></code> | <code>aws-cdk-lib.aws_dynamodb.AttributeType</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.tableClass">tableClass</a></code> | <code>aws-cdk-lib.aws_dynamodb.TableClass</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.readCapacity">readCapacity</a></code> | <code>number</code> | *No description.* |
| <code><a href="#farazgoated.DDBGoatedProps.property.writeCapacity">writeCapacity</a></code> | <code>number</code> | *No description.* |

---

##### `billingMode`<sup>Required</sup> <a name="billingMode" id="farazgoated.DDBGoatedProps.property.billingMode"></a>

```typescript
public readonly billingMode: BillingMode;
```

- *Type:* aws-cdk-lib.aws_dynamodb.BillingMode

---

##### `partitionKeyName`<sup>Required</sup> <a name="partitionKeyName" id="farazgoated.DDBGoatedProps.property.partitionKeyName"></a>

```typescript
public readonly partitionKeyName: string;
```

- *Type:* string

---

##### `partitionKeyType`<sup>Required</sup> <a name="partitionKeyType" id="farazgoated.DDBGoatedProps.property.partitionKeyType"></a>

```typescript
public readonly partitionKeyType: AttributeType;
```

- *Type:* aws-cdk-lib.aws_dynamodb.AttributeType

---

##### `tableClass`<sup>Required</sup> <a name="tableClass" id="farazgoated.DDBGoatedProps.property.tableClass"></a>

```typescript
public readonly tableClass: TableClass;
```

- *Type:* aws-cdk-lib.aws_dynamodb.TableClass

---

##### `readCapacity`<sup>Optional</sup> <a name="readCapacity" id="farazgoated.DDBGoatedProps.property.readCapacity"></a>

```typescript
public readonly readCapacity: number;
```

- *Type:* number

---

##### `writeCapacity`<sup>Optional</sup> <a name="writeCapacity" id="farazgoated.DDBGoatedProps.property.writeCapacity"></a>

```typescript
public readonly writeCapacity: number;
```

- *Type:* number

---
